@@ -4,7 +4,7 @@ from typing import ClassVar, Iterable, Optional
 
 from typing_extensions import TypeGuard
 
-from textual import _widget_navigation
+from textual._loop import loop_from_index
 from textual.await_remove import AwaitRemove
 from textual.binding import Binding, BindingType
 from textual.containers import VerticalScroll
@@ -38,7 +38,7 @@ class ListView(VerticalScroll, can_focus=True, can_focus_children=False):
     | down | Move the cursor down. |
     """
 
-    index = reactive[Optional[int]](0, always_update=True, init=False)
+    index = reactive[Optional[int]](None, init=False)
     """The index of the currently highlighted item."""
 
     class Highlighted(Message):
@@ -117,17 +117,20 @@ class ListView(VerticalScroll, can_focus=True, can_focus_children=False):
         super().__init__(
             *children, name=name, id=id, classes=classes, disabled=disabled
         )
-        # Set the index to the given initial index, or the first available index after.
-        self._index = _widget_navigation.find_next_enabled(
-            children,
-            anchor=initial_index if initial_index is not None else None,
-            direction=1,
-            with_anchor=True,
-        )
+        self._initial_index = initial_index
 
     def _on_mount(self, _: Mount) -> None:
         """Ensure the ListView is fully-settled after mounting."""
-        self.index = self._index
+
+        if self._initial_index is not None and self.children:
+            index = self._initial_index
+            if index >= len(self.children):
+                index = 0
+            if self._nodes[index].disabled:
+                for index, node in loop_from_index(self._nodes, index, wrap=True):
+                    if not node.disabled:
+                        break
+            self.index = index
 
     @property
     def highlighted_child(self) -> ListItem | None:
@@ -165,16 +168,30 @@ class ListView(VerticalScroll, can_focus=True, can_focus_children=False):
 
     def watch_index(self, old_index: int | None, new_index: int | None) -> None:
         """Updates the highlighting when the index changes."""
+
+        if new_index is not None:
+            selected_widget = self._nodes[new_index]
+            if selected_widget.region:
+                self.scroll_to_widget(self._nodes[new_index], animate=False)
+            else:
+                # Call after refresh to permit a refresh operation
+                self.call_after_refresh(
+                    self.scroll_to_widget, selected_widget, animate=False
+                )
+
         if self._is_valid_index(old_index):
             old_child = self._nodes[old_index]
             assert isinstance(old_child, ListItem)
             old_child.highlighted = False
 
-        if self._is_valid_index(new_index) and not self._nodes[new_index].disabled:
+        if (
+            new_index is not None
+            and self._is_valid_index(new_index)
+            and not self._nodes[new_index].disabled
+        ):
             new_child = self._nodes[new_index]
             assert isinstance(new_child, ListItem)
             new_child.highlighted = True
-            self._scroll_highlighted_region()
             self.post_message(self.Highlighted(self, new_child))
         else:
             self.post_message(self.Highlighted(self, None))
@@ -190,8 +207,6 @@ class ListView(VerticalScroll, can_focus=True, can_focus_children=False):
                 until the DOM has been updated with the new child items.
         """
         await_mount = self.mount(*items)
-        if len(self) == 1:
-            self.index = 0
         return await_mount
 
     def append(self, item: ListItem) -> AwaitMount:
@@ -271,27 +286,28 @@ class ListView(VerticalScroll, can_focus=True, can_focus_children=False):
 
     def action_cursor_down(self) -> None:
         """Highlight the next item in the list."""
-        candidate = _widget_navigation.find_next_enabled(
-            self._nodes,
-            anchor=self.index,
-            direction=1,
-        )
-        if self.index is not None and candidate is not None and candidate < self.index:
-            return  # Avoid wrapping around.
-
-        self.index = candidate
+        if self.index is None:
+            if self._nodes:
+                self.index = 0
+        else:
+            index = self.index
+            for index, item in loop_from_index(self._nodes, self.index, wrap=False):
+                if not item.disabled:
+                    self.index = index
+                    break
 
     def action_cursor_up(self) -> None:
         """Highlight the previous item in the list."""
-        candidate = _widget_navigation.find_next_enabled(
-            self._nodes,
-            anchor=self.index,
-            direction=-1,
-        )
-        if self.index is not None and candidate is not None and candidate > self.index:
-            return  # Avoid wrapping around.
-
-        self.index = candidate
+        if self.index is None:
+            if self._nodes:
+                self.index = len(self._nodes) - 1
+        else:
+            for index, item in loop_from_index(
+                self._nodes, self.index, direction=-1, wrap=False
+            ):
+                if not item.disabled:
+                    self.index = index
+                    break
 
     def _on_list_item__child_clicked(self, event: ListItem._ChildClicked) -> None:
         event.stop()
@@ -299,13 +315,6 @@ class ListView(VerticalScroll, can_focus=True, can_focus_children=False):
         self.index = self._nodes.index(event.item)
         self.post_message(self.Selected(self, event.item))
 
-    def _scroll_highlighted_region(self) -> None:
-        """Used to keep the highlighted index within vision"""
-        if self.highlighted_child is not None:
-            self.call_after_refresh(
-                self.scroll_to_widget, self.highlighted_child, animate=False
-            )
-
     def __len__(self) -> int:
         """Compute the length (in number of items) of the list view."""
         return len(self._nodes)
